package fr.iut.pm.movieapplication.repository

import android.util.Log
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.liveData
import fr.iut.pm.movieapplication.api.RetrofitInstance
import fr.iut.pm.movieapplication.api.dtos.PopularDTO
import fr.iut.pm.movieapplication.model.media.MediaResult
import fr.iut.pm.movieapplication.model.media.movie.Movie
import fr.iut.pm.movieapplication.utils.MediaResultMapper
import kotlinx.coroutines.Dispatchers

class MovieRepository {

    suspend fun getPopularMovies(page : Int = 1) : List<Movie>
    {

        val listMovie : MutableList<Movie> = mutableListOf()

        val response = RetrofitInstance.api.getPopularMovies(page = page)
        if(response.isSuccessful) {
            val listMediaResultDTO = response.body()?.results
            listMediaResultDTO?.forEach {
                val movie = MediaResultMapper.mapToMovie(it)
                listMovie.add(movie)
                Log.d("Movie ", movie.title!!)
            }
        }
        else Log.d("ERROR FAILED", response.message())
        return listMovie
    }

    suspend fun getNowPlayingMovies(page : Int = 1) : List<Movie>
    {

        val listMovie : MutableList<Movie> = mutableListOf()

        val response = RetrofitInstance.api.getNowPlayingMovies(page = page)
        if(response.isSuccessful) {
            val listMediaResultDTO = response.body()?.results
            listMediaResultDTO?.forEach {
                val movie = MediaResultMapper.mapToMovie(it)
                listMovie.add(movie)
                Log.d("Movie ", movie.title!!)
            }
        }
        else Log.d("ERROR FAILED", response.message())
        return listMovie
    }

    suspend fun getUpcomingMovies(page : Int = 1)  : List<Movie>
    {

        val listMovie : MutableList<Movie> = mutableListOf()

        val response = RetrofitInstance.api.getUpcomingMovies(page = page)
        if(response.isSuccessful) {
            val listMediaResultDTO = response.body()?.results
            listMediaResultDTO?.forEach {
                val movie = MediaResultMapper.mapToMovie(it)
                listMovie.add(movie)
                Log.d("Movie ", movie.title!!)
            }
        }
        else Log.d("ERROR FAILED", response.message())
        return listMovie
    }

    suspend fun getTopRatedMovies(page : Int = 1)  : List<Movie>
    {

        val listMovie : MutableList<Movie> = mutableListOf()

        val response = RetrofitInstance.api.getTopRatedMovies(page = page)
        if(response.isSuccessful) {
            val listMediaResultDTO = response.body()?.results
            listMediaResultDTO?.forEach {
                val movie = MediaResultMapper.mapToMovie(it)
                listMovie.add(movie)
                Log.d("Movie ", movie.title!!)
            }
        }
        else Log.d("ERROR FAILED", response.message())
        return listMovie
    }


}