package fr.iut.pm.movieapplication.ui.fragments

import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.AdapterView
import android.widget.ArrayAdapter
import android.widget.Spinner
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.lifecycle.Observer
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import fr.iut.pm.movieapplication.R
import fr.iut.pm.movieapplication.databinding.FragmentMoviesBinding
import fr.iut.pm.movieapplication.model.media.movie.Movie
import fr.iut.pm.movieapplication.ui.adapter.MovieAdapter
import fr.iut.pm.movieapplication.ui.viewmodel.MoviesVM
import fr.iut.pm.movieapplication.utils.Constants.Companion.PAGE_SIZE

class MoviesFragment(
) : Fragment() {

    private var isLoading = false
    private var isLastPage = false
    private var currentPage = 1
    private var currentList : MutableList<Movie> = mutableListOf()

    private val moviesVM by viewModels<MoviesVM>()


    lateinit var spinner: Spinner

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        val binding = FragmentMoviesBinding.inflate(inflater)
        binding.moviesVM = moviesVM
        binding.lifecycleOwner = viewLifecycleOwner

            val adapter = ArrayAdapter.createFromResource(
                requireContext(),
                R.array.movie_filter,
                android.R.layout.simple_spinner_item
            )
            adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)

            with(binding.categorySpinner)
            {
                this.adapter = adapter
                onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
                    override fun onItemSelected(
                        parent: AdapterView<*>?,
                        view: View?,
                        position: Int,
                        id: Long
                    ) {
                        moviesVM.getDataFilter(selectedItem.toString())
                    }


                override fun onNothingSelected(parent: AdapterView<*>?) {
                    TODO("Not yet implemented")
                }

            }
        }
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        moviesVM.getMoviesLiveData().observe(viewLifecycleOwner) {
            moviesVM.moviesAdapter.submitList(it)
        }
    }
}
