package fr.iut.pm.movieapplication.ui.viewmodel

import androidx.lifecycle.*
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import fr.iut.pm.movieapplication.model.media.movie.Movie
import fr.iut.pm.movieapplication.repository.MovieRepository
import fr.iut.pm.movieapplication.ui.adapter.MovieAdapter
import kotlinx.coroutines.launch

class MoviesVM() : ViewModel() {
    //Movie repository
    private val repository = MovieRepository()
    //Live data
    private var _moviesLiveData : MutableLiveData<List<Movie>> = MutableLiveData<List<Movie>>()
    fun getMoviesLiveData() : LiveData<List<Movie>> = _moviesLiveData

    private var currentFilter = ""
    val moviesAdapter = MovieAdapter()
    val scrollListener = object : RecyclerView.OnScrollListener() {
        override fun onScrolled(recyclerView: RecyclerView, dx: Int, dy: Int) {
            val layoutManager = recyclerView.layoutManager as GridLayoutManager
            val lastVisibleItemPosition = layoutManager.findLastVisibleItemPosition()
            val totalItemCount = layoutManager.itemCount

            if(lastVisibleItemPosition == totalItemCount -1) {

                ++currentPage
                getMoreData(currentPage)
            }
        }
    }

    private var currentPage = 1


    fun getDataFilter(filter : String) {

        //_moviesLiveData.value = mutableListOf()
        currentFilter = filter
        currentPage = 1

        when(currentFilter) {
            "Populaires" -> viewModelScope.launch {
                _moviesLiveData.postValue(repository.getPopularMovies())
            }
            "Du moment" -> viewModelScope.launch {
                _moviesLiveData.postValue(repository.getNowPlayingMovies())
            }
            "À venir" -> viewModelScope.launch {
                _moviesLiveData.postValue(repository.getUpcomingMovies())
            }
            "Les mieux notés" -> viewModelScope.launch {
                _moviesLiveData.postValue(repository.getTopRatedMovies())
            }
        }

    }

    fun getMoreData(page : Int = 1) {
        var movies : List<Movie>
        when(currentFilter) {
            "Populaires" -> viewModelScope.launch {
                movies = _moviesLiveData.value?.plus(repository.getPopularMovies(page)) ?: listOf()
                _moviesLiveData.postValue(movies)
            }
            "Du moment" -> viewModelScope.launch {
                movies = _moviesLiveData.value?.plus(repository.getNowPlayingMovies(page)) ?: listOf()
                _moviesLiveData.postValue(movies)
            }
            "À venir" -> viewModelScope.launch {
                movies = _moviesLiveData.value?.plus(repository.getUpcomingMovies(page)) ?: listOf()
                _moviesLiveData.postValue(movies)
            }
            "Les mieux notés" -> viewModelScope.launch {
                movies = _moviesLiveData.value?.plus(repository.getTopRatedMovies(page)) ?: listOf()
                _moviesLiveData.postValue(movies)
            }
        }

    }

}



class MoviesVMFactory : ViewModelProvider.Factory {

    override fun <T : ViewModel> create(modelClass: Class<T>): T {
        return MoviesVM() as T
    }

}