package fr.iut.pm.movieapplication.utils

import fr.iut.pm.movieapplication.api.dtos.MediaResultDTO
import fr.iut.pm.movieapplication.model.media.MediaResult
import fr.iut.pm.movieapplication.model.media.movie.Movie
import fr.iut.pm.movieapplication.model.media.tvshow.TvShow

object MediaResultMapper {

     fun mapToTvShow(mediaResultDTO: MediaResultDTO): TvShow {
        return TvShow(
            posterPath = mediaResultDTO.posterPath,
            popularity = mediaResultDTO.popularity,
            id = mediaResultDTO.id,
            backdropPath = mediaResultDTO.backdropPath!!,
            voteAverage = mediaResultDTO.voteAverage,
            overview = mediaResultDTO.overview,
            firstAirDate = mediaResultDTO.firstAirDate,
            originCountry = mediaResultDTO.originCountry!!,
            genreIds = mediaResultDTO.genreIds,
            originalLanguage = mediaResultDTO.originalLanguage,
            voteCount = mediaResultDTO.voteCount,
            name = mediaResultDTO.name!!,
            originalName = mediaResultDTO.originalName!!
        )
    }

     fun mapToMovie(mediaResultDTO: MediaResultDTO): Movie {
        return Movie(
            posterPath = mediaResultDTO.posterPath,
            adult = !mediaResultDTO.adult,
            overview = mediaResultDTO.overview,
            releaseDate = mediaResultDTO.releaseDate ?: "",
            genreIds = mediaResultDTO.genreIds,
            id = mediaResultDTO.id,
            originalTitle = mediaResultDTO.originalTitle!!,
            originalLanguage = mediaResultDTO.originalLanguage,
            title = mediaResultDTO.title,
            backdropPath = mediaResultDTO.backdropPath,
            popularity = mediaResultDTO.popularity,
            voteCount = mediaResultDTO.voteCount,
            video = mediaResultDTO.video,
            voteAverage = mediaResultDTO.voteAverage
        )
    }

    fun mapToMediaResult(mediaResultDTO: MediaResultDTO) : MediaResult {
        return MediaResult(
            posterPath = mediaResultDTO.posterPath,
            adult = !mediaResultDTO.adult,
            overview = mediaResultDTO.overview,
            releaseDate = mediaResultDTO.releaseDate ?: mediaResultDTO.firstAirDate!! ,
            originCountry = mediaResultDTO.originCountry,
            genreIds = mediaResultDTO.genreIds,
            id = mediaResultDTO.id,
            originalTitle = mediaResultDTO.originalTitle ?: mediaResultDTO.originalName!!, //if it's not a movie also it's a tvshow
            originalLanguage = mediaResultDTO.originalLanguage,
            title = mediaResultDTO.title ?: mediaResultDTO.name!!, //if it's not a movie also it's a tvshow
            backdropPath = mediaResultDTO.backdropPath,
            popularity = mediaResultDTO.popularity,
            voteCount = mediaResultDTO.voteCount,
            voteAverage = mediaResultDTO.voteAverage,
            mediaType = mediaResultDTO.mediaType
        )
    }


}